@@ -5,7 +5,6 @@ package setters2
 
 import (
 	"io/ioutil"
-	"os"
 	"path/filepath"
 	"strings"
 	"testing"
@@ -1002,10 +1001,9 @@ spec:
 
 // initSchema initializes the openAPI with the definitions from s
 func SettersSchema(t *testing.T, s string) *spec.Schema {
-	dir, err := ioutil.TempDir("", "")
-	assert.NoError(t, err)
-	defer os.RemoveAll(dir)
-	err = ioutil.WriteFile(filepath.Join(dir, "Krmfile"), []byte(s), 0600)
+	t.Helper()
+	dir := t.TempDir()
+	err := ioutil.WriteFile(filepath.Join(dir, "Krmfile"), []byte(s), 0600)
 	if !assert.NoError(t, err) {
 		t.FailNow()
 	}
@@ -1553,7 +1551,7 @@ func TestValidateAgainstSchema(t *testing.T) {
 				},
 			},
 			shouldValidate:   false,
-			expectedErrorMsg: "foo in body must be of type integer",
+			expectedErrorMsg: "foo[2] in body must be of type integer",
 		},
 		{
 			name: "all values should satisfy type string",
