@@ -1168,7 +1168,6 @@ items:
 				assert.NotNil(t, err)
 				assert.Equal(t, tc.expectedErr.Error(), err.Error())
 			}
-
 		})
 	}
 }
@@ -2181,8 +2180,7 @@ func TestRoundTripJSON(t *testing.T) {
 	if err != nil {
 		t.Fatalf("unexpected MarshalJSON err: %v", err)
 	}
-	actual := string(data)
-	if actual != deploymentLittleJson {
+	if actual := string(data); actual != deploymentLittleJson {
 		t.Fatalf("expected %s, got %s", deploymentLittleJson, actual)
 	}
 }
@@ -2310,3 +2308,27 @@ func TestGetAnnotations(t *testing.T) {
 		t.Fatalf("expected '%s', got '%s'", expected, actual)
 	}
 }
+
+func TestGetFieldValueWithDot(t *testing.T) {
+	const input = `
+kind: Pod
+metadata:
+  name: hello-world
+  labels:
+    app: hello-world-app
+    foo.appname: hello-world-foo
+`
+	data, err := Parse(input)
+	require.NoError(t, err)
+
+	labelRNode, err := data.Pipe(Lookup("metadata", "labels"))
+	require.NoError(t, err)
+
+	app, err := labelRNode.GetFieldValue("app")
+	require.NoError(t, err)
+	require.Equal(t, "hello-world-app", app)
+
+	fooAppName, err := labelRNode.GetFieldValue(`foo\.appname`)
+	require.NoError(t, err)
+	require.Equal(t, "hello-world-foo", fooAppName) // no field named 'foo.appname'
+}
